@@ -14,11 +14,11 @@ our @ISA = qw( Exporter DynaLoader );
 our %EXPORT_TAGS = ( 'all' => [ 'new', 'distance_to' ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = ();
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 XSLoader::load 'Geo::Calc::XS', $VERSION;
 
-# Copyrights 2011-2012 by Sorin Alexandru Pop.
+# Copyright 2011-2012 by Sorin Alexandru Pop.
 # For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 
@@ -31,6 +31,10 @@ Geo::Calc::XS - simple geo calculator for points and distances
  use Geo::Calc::XS;
 
  my $gc            = Geo::Calc::XS->new( lat => 40.417875, lon => -3.710205 );
+ my $lan           = $gc->get_lan();
+ my $lon           = $gc->get_lon();
+ my $radius        = $gc->get_radius();
+ my $units         = $gc->get_units();
  my $distance      = $gc->distance_to( { lat => 40.422371, lon => -3.704298 }, -6 );
  my $brng          = $gc->bearing_to( { lat => 40.422371, lon => -3.704298 }, -6 );
  my $f_brng        = $gc->final_bearing_to( { lat => 40.422371, lon => -3.704298 }, -6 );
@@ -44,30 +48,47 @@ Geo::Calc::XS - simple geo calculator for points and distances
 
 =head1 DESCRIPTION
 
-C<Geo::Calc::XS> implements a variety of calculations for latitude/longitude points
+B<Geo::Calc::XS> implements a variety of calculations for latitude/longitude points
 
-All these formulare are for calculations on the basis of a spherical earth
-(ignoring ellipsoidal effects) which is accurate enough* for most purposes.
+All these formulas are for calculations on the basis of a spherical earth
+(ignoring ellipsoidal effects), which is accurate enough for most purposes.
 
 [ In fact, the earth is very slightly ellipsoidal; using a spherical model
 gives errors typically up to 0.3% ].
 
-Benchmarnking this module and Geo::Calc I found out that this module is sometime
+Benchmarking this module and L<Geo::Calc> I found out that this module is sometimes
 more than 8000 times faster.
 
+=head1 CAVEATS
+
+=over 4
+
+=item
+
+This module is not thread-safe.
+
+=item
+
+This is not a drop-in replacement for L<Geo::Calc>, see the COMPATIBILITY
+section further down.
+
+=back
+
 =head1 Geo::Calc::XS->new()
 
  $gc = Geo::Calc::XS->new( lat => 40.417875, lon => -3.710205 ); # Somewhere in Madrid
  $gc = Geo::Calc::XS->new( lat => 51.503269, lon => 0, units => 'k-m' ); # The O2 Arena in London
 
 Creates a new Geo::Calc::XS object from a latitude and longitude. The default
-deciaml precision is -6 for all functions => meaning by default it always
-returns the results with 6 deciamls.
+decimal precision is -6 for all functions => meaning by default it always
+returns the results with 6 decimals.
 
-The default unit distance is 'm' (meter), but you cand define another unit using 'units'.
+The default unit distance is 'm' (meter), but you cand define another unit using C<units>.
 Accepted values are: 'm' (meters), 'k-m' (kilometers), 'yd' (yards), 'ft' (feet) and 'mi' (miles)
 
-Returns ref to a Geo::Calc::XS object.
+If a C<radius> parameter is passed, it is ignored.
+
+Returns a reference to a C<Geo::Calc::XS> object.
 
 =head2 Parameters
 
@@ -78,19 +99,19 @@ C<get_lon>, C<get_radius> or C<get_units>.
 
 =item lat
 
-C<>=> latitude of the point ( required )
+=> latitude of the point ( required )
 
 =item lon
 
-C<>=> longitude of the point ( required )
+=> longitude of the point ( required )
 
 =item radius
 
-C<>=> earth radius in km ( defaults to 6371 )
+=> earth radius in km ( defaults to 6371 )
 
 =item units
 
-C<>=> the distance unit received and output by this object ( default to 'm' )
+=> the distance unit received and output by this object ( defaults to 'm' )
 
 =back
 
@@ -139,7 +160,7 @@ you from the start point to the end point
 Returns the (initial) bearing from this point to the supplied point, in degrees
 with the specified pricision
 
-see http://williams.best.vwh.net/avform.htm#Crs
+See L<http://williams.best.vwh.net/avform.htm#Crs>
 
 =cut
 
@@ -164,7 +185,7 @@ degrees according to distance and latitude
 Returns the midpoint along a great circle path between the initial point and
 the supplied point.
 
-see http://mathforum.org/library/drmath/view/51822.html for derivation
+See L<http://mathforum.org/library/drmath/view/51822.html> for derivation
 
 =cut
 
@@ -181,19 +202,6 @@ C<$distance> must be specified in this object's distance unit.
 
 =cut
 
-=head2 destination_point_hs
-
- $gc->destination_point_hs( $bearing, $distance[, $precision] );
- $gc->destination_point_hs( 90, 1 );
-
-Returns the destination point from this point having travelled the given
-distance on the given initial bearing (bearing may vary before destination is
-reached)
-
-see http://williams.best.vwh.net/avform.htm#LL
-
-=cut
-
 =head2 boundry_box
 
  $gc->boundry_box( $width[, $height[, $precision]] );
@@ -233,7 +241,7 @@ great circle . important for aviation fuel, but not particularly to sailing
 vessels. New York to Beijing . close to the most extreme example possible
 (though not sailable!) . is 30% longer along a rhumb line.
 
-see http://williams.best.vwh.net/avform.htm#Rhumb
+See L<http://williams.best.vwh.net/avform.htm#Rhumb>
 
 =cut
 
@@ -267,7 +275,7 @@ line.
 
 Returns the point of intersection of two paths defined by point and bearing
 
-see http://williams.best.vwh.net/avform.htm#Intersection
+See L<http://williams.best.vwh.net/avform.htm#Intersection>
 
 =cut
 
@@ -286,9 +294,31 @@ compatibility.
 
 =head1 COMPATIBILITY
 
-A C<Geo::Calc::XS> object has the same interface as a C<Geo::Calc> object.
-However, the results returned by these objects may differ in the latter decimal
-points, due to the differing implementation.
+A B<Geo::Calc::XS> object does not have the same interface as a L<Geo::Calc>
+object, despite the similarities.
+
+Here are the currently known differences:
+
+=over 4
+
+=item
+
+C<destination_point_hs> is provided by L<Geo::Calc> but not by this module.
+
+=item
+
+The constructor for L<Geo::Calc> accepts a C<radius> parameter, but this module ignores it.
+
+=item
+
+Methods with identicial names perform similar functions but may return
+different results after a few decimal places.
+
+=item
+
+L<Geo::Calc> may be thread-safe, whereas this module definitely is not.
+
+=back
 
 =head1 SEE ALSO
 
@@ -304,7 +334,7 @@ L<https://github.com/Flimm/perl5-geo-calc-xs>
 All complex software has bugs lurking in it, and this module is no
 exception.
 
-Please report any bugs through the web interface at L<http://rt.cpan.org>.
+Please report any bugs through the web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Geo-Calc-XS>.
 
 =head1 AUTHOR
 
@@ -313,7 +343,9 @@ Sorin Alexandru Pop C<< <asp@cpan.org> >>
 =head1 THANKS
 
 Marius Crisan C<< <crisan.marius@gmail.com> >>
-David D Lowe C<< <daviddlowe.flimm@gmail.com> >>
+
+David D Lowe C<< <flimm@cpan.org> >>
+
 Chris Hughes C<< <chris@lokku.com> >>
 
 =head1 LICENSE
